@@ -1,6 +1,6 @@
 package Catalyst::View::Component::SubInclude::ESI;
-use Moose;
-use namespace::clean -except => 'meta';
+use warnings;
+use strict;
 
 =head1 NAME
 
@@ -8,12 +8,11 @@ Catalyst::View::Component::SubInclude::ESI - Edge Side Includes (ESI) plugin for
 
 =head1 VERSION
 
-Version 0.07_03
+Version 0.01
 
 =cut
 
-our $VERSION = '0.07_03';
-$VERSION = eval $VERSION;
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -40,13 +39,11 @@ uses of includes.
 
 =head1 CLASS METHODS
 
-=head2 C<generate_subinclude( $c, $path, @args )>
+=head2 C<generate_subinclude( $c, @args )>
 
-Note that C<$path> should be the private action path - translation to the public
-path is handled internally. After translation, this will roughly translate to 
-the following code:
+This will roughly translate to the following code:
 
-  my $url = $c->uri_for( $translated_path, @args )->path_query;
+  my $url = $c->uri_for( @args );
   return '<!--esi <esi:include src="$url" /> -->';
 
 Notice that the stash will always be empty. This behavior could be configurable
@@ -56,11 +53,10 @@ common interface for plugins.
 =cut
 
 sub generate_subinclude {
-    my ($self, $c, $path, @params) = @_;
-
-    my $uri = $c->uri_for_action( $path, @params );
-
-    return '<!--esi <esi:include src="' . $uri->path_query . '" /> -->';
+    my $class = shift;
+    my $c     = shift;
+    my $url = $c->uri_for( @_ );
+    return '<!--esi <esi:include src="' . $url->path . '" /> -->';
 }
 
 =head1 SEE ALSO
@@ -88,5 +84,4 @@ under the same terms as Perl itself.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
 1;
