@@ -1,8 +1,9 @@
 package Catalyst::View::Component::SubInclude::SubRequest;
-use Moose;
+use warnings;
+use strict;
+
 use Carp qw/croak/;
-use MooseX::Types::Moose qw/ Bool /;
-use namespace::clean -except => 'meta';
+use namespace::clean qw/croak/;
 
 =head1 NAME
 
@@ -10,11 +11,11 @@ Catalyst::View::Component::SubInclude::SubRequest - Sub-requests plugin for C::V
 
 =head1 VERSION
 
-Version 0.07
+Version 0.01
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -54,42 +55,24 @@ It requires L<Catalyst::Plugin::SubRequest>.
 
 =head2 C<generate_subinclude( $c, $path, @args )>
 
-This will make a sub-request call to the action specified by C<$path>. Note that
-C<$path> should be the private action path - translation to the public path is
-handled internally.
+This will translate to the following sub-request call:
 
-So, after path translation, the call will be (roughly) equivalent to:
-
-  $c->sub_request( $translated_path, {}, @args );
+  $c->sub_request( $path, {}, @args );
 
 Notice that the stash will always be empty. This behavior could be configurable
 in the future through an additional switch - for now, this behavior guarantees a
-common interface for all plugins.
+common interface for plugins.
 
 =cut
 
-has keep_stash => (
-    isa => Bool,
-    is => 'ro',
-    default => 0,
-);
-
 sub generate_subinclude {
-    my ($self, $c, $path, @params) = @_;
-    my $stash = $self->keep_stash ? { %{ $c->stash } } : {};
+    my ($class, $c, $path, @params) = @_;
+    my $stash = {};
 
     croak "subincludes through subrequests require Catalyst::Plugin::SubRequest"
         unless $c->can('sub_request');
 
-    my $query = ref $params[-1] eq 'HASH' ? pop @params : {};
-    
-    my $action = blessed($path)
-          ? $path
-          : $c->dispatcher->get_action_by_path($path);
-
-    my $uri = $c->uri_for( $action, @params );
-
-    $c->sub_request( $uri->path, $stash, $query );
+    $c->sub_request( $path, $stash, @params );
 }
 
 =head1 SEE ALSO
@@ -116,5 +99,4 @@ under the same terms as Perl itself.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
 1;
